@@ -621,7 +621,7 @@ def dbmigrate_docker(containerid, codepath='/data/deploy/current'):
 # These atomic tasks for putting the new deploy into effect are preferred, as they
 # may run in parallel, while minimizing the exposure between the swap_code and putting the new code into effect
 #
-supervisor = "/usr/bin/supervisorctl"
+supervisor = "supervisorctl"
 
 
 @task
